==> ejc-task-api-3.0.0-20210123.085528-9-sources.jar: com/ejianc/business/warn/vo/WarningParameterVO.java <==
package com.ejianc.business.warn.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class WarningParameterVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
     * 参数类型
     */
    private String parameterType;
	
	/**
     * 参数名称
     */
    private String parameterName;
	
	/**
     * 主表键值
     */
    private Long warningId;
	
	/**
     * 参数条件
     */
    private String parameterCondition;
	
	/**
     * 参数值
     */
    private String parameterValue;
	
	/**
     * 参数单位
     */
    private String parameterUnit;
	
	/**
     * 参数属性
     */
    private String parameterProperty;

	public String getParameterType() {
		return parameterType;
	}

	public void setParameterType(String parameterType) {
		this.parameterType = parameterType;
	}

	public String getParameterName() {
		return parameterName;
	}

	public void setParameterName(String parameterName) {
		this.parameterName = parameterName;
	}

	public Long getWarningId() {
		return warningId;
	}

	public void setWarningId(Long warningId) {
		this.warningId = warningId;
	}

	public String getParameterCondition() {
		return parameterCondition;
	}

	public void setParameterCondition(String parameterCondition) {
		this.parameterCondition = parameterCondition;
	}

	public String getParameterValue() {
		return parameterValue;
	}

	public void setParameterValue(String parameterValue) {
		this.parameterValue = parameterValue;
	}

	public String getParameterUnit() {
		return parameterUnit;
	}

	public void setParameterUnit(String parameterUnit) {
		this.parameterUnit = parameterUnit;
	}

	public String getParameterProperty() {
		return parameterProperty;
	}

	public void setParameterProperty(String parameterProperty) {
		this.parameterProperty = parameterProperty;
	}

}

==> ejc-task-api-3.0.0-20210303.005729-33-sources.jar: com/ejianc/business/warn/vo/WarningParameterVO.java <==
package com.ejianc.business.warn.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

public class WarningParameterVO extends BaseVO {

	private static final long serialVersionUID = 1L;

	/**
	 * 预警参数状态： 启用
	 */
	public static final String WARN_PARAM_STATE_ENABLE = "1";

	/**
	 * 预警参数状态：停用
	 */
	public static final String WARN_PARAM_STATE_DIENABLE = "0";

	/**
     * 参数类型
     */
    private String parameterType;
	
	/**
     * 参数名称
     */
    private String parameterName;
	
	/**
     * 主表键值
     */
    private Long warningId;
	
	/**
     * 参数条件
     */
    private String parameterCondition;
	
	/**
     * 参数值
     */
    private String parameterValue;
	
	/**
     * 参数单位
     */
    private String parameterUnit;
	
	/**
     * 参数属性
     */
    private String parameterProperty;

	/**
	 * 参数启用状态：0-停用，1-启用
	 */
	private String enableState;

	public String getParameterType() {
		return parameterType;
	}

	public void setParameterType(String parameterType) {
		this.parameterType = parameterType;
	}

	public String getParameterName() {
		return parameterName;
	}

	public void setParameterName(String parameterName) {
		this.parameterName = parameterName;
	}

	public Long getWarningId() {
		return warningId;
	}

	public void setWarningId(Long warningId) {
		this.warningId = warningId;
	}

	public String getParameterCondition() {
		return parameterCondition;
	}

	public void setParameterCondition(String parameterCondition) {
		this.parameterCondition = parameterCondition;
	}

	public String getParameterValue() {
		return parameterValue;
	}

	public void setParameterValue(String parameterValue) {
		this.parameterValue = parameterValue;
	}

	public String getParameterUnit() {
		return parameterUnit;
	}

	public void setParameterUnit(String parameterUnit) {
		this.parameterUnit = parameterUnit;
	}

	public String getParameterProperty() {
		return parameterProperty;
	}

	public void setParameterProperty(String parameterProperty) {
		this.parameterProperty = parameterProperty;
	}

	public String getEnableState() {
		return enableState;
	}

	public void setEnableState(String enableState) {
		this.enableState = enableState;
	}
}
